;; Generated package description from adjust-parens.el  -*- no-byte-compile: t -*-
(define-package "adjust-parens" "3.1.0.20221221.73810" "Indent and dedent Lisp code, automatically adjust close parens" 'nil :commit "e6723f0fd214197dbcc69ae5898a166cc3662b9b" :url "https://elpa.gnu.org/packages/adjust-parens.html" :authors '(("Barry O'Reilly" . "gundaetiapo@gmail.com")) :maintainer '("Barry O'Reilly" . "gundaetiapo@gmail.com"))
